package org.eclipse.persistence.example.sdo.staticapi;

import java.io.FileInputStream;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import commonj.sdo.helper.DataFactory;
import commonj.sdo.helper.XMLDocument;
import commonj.sdo.helper.XSDHelper;
import commonj.sdo.helper.XMLHelper;

import org.example.customer_example.AddressType;
import org.example.customer_example.CustomerType;
import org.example.customer_example.PhoneNumber;

public class Example {

    public static void main(String[] args) throws Exception {
        // = Initialize the types ==============================================
        FileInputStream xsdInputStream = new FileInputStream("config/Customer.xsd");
        XSDHelper.INSTANCE.define(xsdInputStream, null);
        
        // = Unmarshal the XML document ========================================
        FileInputStream xmlInputStream = new FileInputStream("config/Customer-data.xml");
        XMLDocument xmlDocument = XMLHelper.INSTANCE.load(xmlInputStream);
        CustomerType customer = (CustomerType) xmlDocument.getRootObject(); 
        
        // = Turn on change tracking ===========================================
        customer.getChangeSummary().beginLogging();
        
        // = Modify the ShippingAddress ZipCode ================================
        AddressType address = customer.getContactInfo().getShippingAddress();
        address.setZipCode("27601");

        // = Add a new PhoneNumber =============================================
        PhoneNumber newPhoneNumber = (PhoneNumber) DataFactory.INSTANCE.create("http://www.example.org/customer-example", "phone-number");
        newPhoneNumber.setNumberType("home");
        newPhoneNumber.setValue("(613) 555-3333");
        customer.getContactInfo().getPhoneNumber().add(newPhoneNumber);

        // = Remove all "cell" PhoneNumbers ====================================
        ArrayList phoneNumbersToRemove = new ArrayList();
        List phoneNumbers = customer.getContactInfo().getPhoneNumber();
        Iterator it = phoneNumbers.iterator();
        while (it.hasNext()) {
            PhoneNumber phoneNumber = (PhoneNumber) it.next();
            if (phoneNumber.getNumberType().equals("cell")) {
                phoneNumbersToRemove.add(phoneNumber);
            }
        }
        phoneNumbers.removeAll(phoneNumbersToRemove);
 
        // = Turn off change tracking ==========================================
        customer.getChangeSummary().endLogging();
        
        // = Marshal the Java object back to an XML document ===================
        XMLHelper.INSTANCE.save(xmlDocument, System.out, null);
    }
   
}